import ColHeader from '@/components/col-header'
import { defineComponent } from 'vue'
import styles from './teacher-home.module.less'
import { Button, Cell, Icon, Image, Rate, Sticky, Tab, Tabs, Toast } from 'vant'

import iconTeacher from '@common/images/icon_teacher.png'
import musicCert from '@common/images/music_cert.png'
import teacherCert from '@common/images/teacher_cert.png'
import Single from './components/single'
import Practice from './components/practice'
import Live from './components/live'
import VideoList from './components/video'
import Music from './components/music'
import request from '@/helpers/request'

export const getAssetsHomeFile = (fileName: string) => {
  const path = `./images/${fileName}`
  const modules = import.meta.globEager('./images/*')
  return modules[path].default
}

export default defineComponent({
  name: 'teacherHome',
  data() {
    // 先取session中的数据，没有再取参数，默认为老师风采
    const tabs = sessionStorage.getItem('teacherHomeTabs') || ''
    const query = this.$route.query
    return {
      teacherId: query.teacherId,
      tabs: tabs || query.tabs || 'single',
      userInfo: {} as any
    }
  },
  async created() {
    try {
      const res = await request.get('/api-student/teacher/queryTeacherHome', {
        params: {
          userId: this.teacherId
        }
      })
      // const result = res.data
      this.userInfo = res.data
      // console.log(result)
    } catch {}
  },
  computed: {
    subjectNameList() {
      const userInfo: any = this.userInfo
      const subjectName = userInfo.subjectName
      return subjectName ? subjectName.split(',') : []
    }
  },
  methods: {
    async onStart() {
      // 关注与取消关注
      try {
        const star = this.userInfo.isStar ? 0 : 1
        await request.get('/api-student/teacher/starOrUnStar', {
          params: {
            userId: this.teacherId,
            starStatus: star
          }
        })
        const str = star ? '关注成功' : '已取消关注'
        this.userInfo.isStar = star
        let count = star ? this.userInfo.fansNum + 1 : this.userInfo.fansNum - 1
        this.userInfo.fansNum = count <= 0 ? 0 : count
        Toast(str)
      } catch {}
    }
  },
  render() {
    return (
      <div class={styles['teacher-record']}>
        <Sticky position="top" offsetTop={0}>
          <ColHeader
            class={styles.teacherHeader}
            background="transparent"
            border={false}
            color="#fff"
            backIconColor="white"
            isFixed={false}
            v-slots={{
              default: () => (
                <div class={styles.headerContent}>
                  <div class={styles.headerCount}>
                    <Cell
                      class={styles['open-teacher-info']}
                      border={false}
                      center
                      v-slots={{
                        icon: () => (
                          <Image
                            class={styles.userLogo}
                            src={this.userInfo.heardUrl || iconTeacher}
                            fit="cover"
                          />
                        )
                      }}
                    >
                      <div class={styles['teacher-info']}>
                        <div class={styles['teacher-name']}>
                          <div class={styles.teacherCert}>
                            <span style={{ display: 'inline-block' }}>
                              {this.userInfo.username ||
                                `游客${this.userInfo.userId || ''}`}
                            </span>

                            {this.userInfo.entryFlag === 1 && (
                              <Image
                                class={styles.cert}
                                src={teacherCert}
                                // fit="contain"
                              />
                            )}
                            {this.userInfo.musicianFlag === 1 && (
                              <Image
                                class={styles.cert}
                                src={musicCert}
                                // fit="contain"
                              />
                            )}
                          </div>
                          <Button
                            type="primary"
                            size="mini"
                            plain={!!this.userInfo.isStar}
                            style={{ borderRadius: '5px', padding: '5px 10px' }}
                            onClick={this.onStart}
                          >
                            {!this.userInfo.isStar && <Icon name="plus" />}

                            {this.userInfo.isStar ? '已关注' : '关注'}
                          </Button>
                        </div>
                        <p class={styles.piNameSubject}>
                          {this.subjectNameList.map((item: any) => (
                            <span class={styles.subject}>{item}</span>
                          ))}
                        </p>
                      </div>
                    </Cell>
                    <div class={styles['teacher-bottom']}>
                      <div class={styles.level}>
                        <Rate
                          iconPrefix="iconfont"
                          color="#FFC459"
                          void-icon="star_default"
                          modelValue={this.userInfo.starGrade}
                          icon="star_active"
                          size={15}
                        />
                      </div>
                      <div class={styles['teacher-data']}>
                        <div class={styles['teacher-data_item']}>
                          粉丝 <span>{this.userInfo.fansNum || 0}</span>
                        </div>
                        <div class={styles['teacher-data_item']}>
                          已上课时 <span>{this.userInfo.expTime || 0}</span>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              )
            }}
          />
          <Tabs
            color="var(--van-primary)"
            background="#f8f9fc"
            lineWidth={20}
            v-model:active={this.tabs}
            onChange={() => {
              sessionStorage.setItem('teacherHomeTabs', this.tabs as string)
            }}
          >
            <Tab title="个人风采" name="single"></Tab>
            <Tab title="陪练课" name="practice"></Tab>
            <Tab title="直播课" name="live"></Tab>
            <Tab title="视频课" name="video"></Tab>
            <Tab title="乐谱" name="music"></Tab>
          </Tabs>
        </Sticky>
        {/* </div> */}

        <div class={styles.container}>
          {this.tabs === 'single' && <Single userInfo={this.userInfo} />}
          {this.tabs === 'practice' && <Practice userInfo={this.userInfo} />}
          {this.tabs === 'live' && <Live />}
          {this.tabs === 'video' && <VideoList />}
          {this.tabs === 'music' && <Music />}
        </div>
      </div>
    )
  }
})
