import { Cell, CellGroup, Image } from 'vant'
import { defineComponent } from 'vue'
import styles from './index.module.less'

import iconTeacher from '@common/images/icon_teacher.png'
import { orderStatus } from '../orderStatus'
import request from '@/helpers/request'

export default defineComponent({
  name: 'OrderLive',
  props: {
    modelValue: {
      type: Number,
      default: 0
    }
  },
  methods: {
    async onSubmit() {
      console.log('video submit')
      try {
        const res = await request.post('/api-student/userOrder/executeOrder', {
          data: {
            orderName: '直播课购买',
            orderDesc: '直播课购买',
            orderType: 'LIVE',
            actualPrice: orderStatus.liveInfo.coursePrice || 0,
            orderInfos: [
              {
                goodType: 'LIVE',
                goodName: '直播课购买',
                bizContent: {
                  groupId: orderStatus.liveInfo.courseGroupId
                }
              }
            ]
          }
        })
        return res.data
      } catch {
        return false
      }
    }
  },
  computed: {
    coursePlan() {
      const live = orderStatus.liveInfo || {}
      return live.courseInfo || []
    }
  },
  mounted() {
    const price = orderStatus.liveInfo.coursePrice || 0
    this.$emit('update:modelValue', price)
  },
  render() {
    return (
      <div class={styles.liveOrder}>
        <CellGroup border={false}>
          <Cell titleClass={styles.title} title="课程名称" />
          <Cell
            title={orderStatus.liveInfo.courseGroupName}
            v-slots={{
              default: () => (
                <span class={styles.price}>
                  <i>¥</i>
                  {(this as any).$filters.moneyFormat(
                    orderStatus.liveInfo.coursePrice
                  )}
                </span>
              )
            }}
          />
        </CellGroup>

        <CellGroup border={false}>
          <Cell titleClass={styles.title} title="主讲老师" />
          <Cell
            class={styles.titleName}
            title={orderStatus.liveInfo.teacherName}
            v-slots={{
              icon: () => (
                <Image
                  class={styles.userLogo}
                  src={orderStatus.liveInfo.avatar || iconTeacher}
                />
              )
            }}
          />
        </CellGroup>

        <CellGroup border={false}>
          <Cell
            titleClass={styles.title}
            title="上课时间"
            value={`（共${this.coursePlan.length}课时）`}
          />
          <Cell
            v-slots={{
              title: () => (
                <div>
                  {this.coursePlan.map((item: any) => (
                    <div class={styles.classItem}>
                      <div class={styles.time}>{item.courseTime}</div>
                      {/* <p>19:25 - 20:00</p>
                      <p>19:25 - 20:00</p> */}
                    </div>
                  ))}
                </div>
              )
            }}
          />
        </CellGroup>
      </div>
      // 视频课
    )
  }
})
