import { Cell, CellGroup, Image, Rate } from 'vant'
import { defineComponent } from 'vue'
import styles from './index.module.less'
import { orderStatus } from '../orderStatus'

import iconTeacher from '@common/images/icon_teacher.png'
import request from '@/helpers/request'
import item from '@/teacher/music/list/item'

export default defineComponent({
  name: 'OrderPractice',
  props: {
    modelValue: {
      type: Number,
      default: 0
    }
  },
  computed: {
    coursePlan() {
      const practice = orderStatus.practiceInfo || {}
      console.log(practice.classTime)
      return practice.classTime || []
    },
    bizContent() {
      const {
        courseGroupName,
        courseIntroduce,
        subjectId,
        singleCourseMinutes,
        courseNum,
        coursePrice,
        teacherId,
        classTime
      } = orderStatus.practiceInfo
      let tempTime = classTime || []
      let classCourse: any = []
      tempTime.forEach((time: any) => {
        classCourse.push({
          classDate: time.classDate,
          startTime: time.startTime,
          endTime: time.endTime
        })
      })
      return {
        courseGroupName,
        courseIntroduce,
        subjectId,
        singleCourseMinutes,
        courseNum,
        coursePrice,
        teacherId,
        classTime: classCourse
      }
    }
  },
  mounted() {
    const price = Number(orderStatus.practiceInfo.coursePrice) || 0
    console.log(orderStatus.practiceInfo, 11212)
    this.$emit('update:modelValue', price)
  },
  methods: {
    async onSubmit() {
      console.log('video submit')
      try {
        const res = await request.post('/api-student/userOrder/executeOrder', {
          data: {
            orderName: '陪练课购买',
            orderDesc: '陪练课购买',
            orderType: 'PRACTICE',
            actualPrice: orderStatus.practiceInfo.coursePrice || 0,
            orderInfos: [
              {
                goodType: 'PRACTICE',
                goodName: '陪练课购买',
                bizContent: {
                  ...this.bizContent
                }
              }
            ]
          }
        })
        return res.data
      } catch {
        return false
      }
    }
  },
  render() {
    return (
      <div class={styles.videoOrder}>
        <CellGroup border={false}>
          <Cell titleClass={styles.title} title="预约老师" />
          <Cell
            center
            v-slots={{
              icon: () => (
                <Image
                  class={styles.userLogo}
                  src={orderStatus.practiceInfo.avatar || iconTeacher}
                />
              ),
              title: () => (
                <div class={styles.titleName}>
                  <p>{orderStatus.practiceInfo.teacherName}</p>
                  <Rate
                    iconPrefix="iconfont"
                    color="#FFC459"
                    void-icon="star_default"
                    modelValue={orderStatus.practiceInfo.starGrade}
                    icon="star_active"
                    size={15}
                  />
                </div>
              )
            }}
          />
        </CellGroup>
        <CellGroup border={false}>
          <Cell titleClass={styles.title} title="课程信息" />
          <Cell
            title={orderStatus.practiceInfo.courseGroupName}
            v-slots={{
              default: () => (
                <div class={styles.price}>
                  <span>
                    ¥
                    {(this as any).$filters.moneyFormat(
                      orderStatus.practiceInfo.coursePrice
                    )}
                  </span>
                  /{orderStatus.practiceInfo.singleCourseMinutes}分钟
                </div>
              )
            }}
          />
        </CellGroup>

        <CellGroup border={false}>
          <Cell
            titleClass={styles.title}
            title="上课时间"
            value={`（共${this.coursePlan.length}课时）`}
          />
          <Cell
            v-slots={{
              title: () => (
                <div>
                  {this.coursePlan.map((item: any) => (
                    <div class={styles.classItem}>
                      <div class={styles.time}>{item.title}</div>
                    </div>
                  ))}
                </div>
              )
            }}
          />
        </CellGroup>
      </div>
      // 视频课
    )
  }
})
