import { Cell, CellGroup, Image } from 'vant'
import { defineComponent } from 'vue'
import styles from './index.module.less'
import { orderStatus } from '../orderStatus'

import iconTeacher from '@common/images/icon_teacher.png'
import request from '@/helpers/request'

export default defineComponent({
  name: 'OrderVideo',
  props: {
    modelValue: {
      type: Number,
      default: 0
    }
  },
  computed: {
    coursePlan() {
      const video = orderStatus.videoInfo || {}
      return video.courseInfo || []
    }
  },
  mounted() {
    const price = orderStatus.videoInfo.coursePrice || 0
    console.log(orderStatus.videoInfo, 11212)
    this.$emit('update:modelValue', price)
  },
  methods: {
    async onSubmit() {
      console.log('video submit')
      try {
        const res = await request.post('/api-student/userOrder/executeOrder', {
          data: {
            orderName: '视频课购买',
            orderDesc: '视频课购买',
            orderType: 'VIDEO',
            actualPrice: orderStatus.videoInfo.coursePrice || 0,
            orderInfos: [
              {
                goodType: 'VIDEO',
                goodName: '视频课购买',
                bizContent: {
                  videoLessonGroupId: orderStatus.videoInfo.courseGroupId,
                  payMoney: orderStatus.videoInfo.coursePrice || 0
                }
              }
            ]
          }
        })
        return res.data
      } catch {
        return false
      }
    }
  },
  render() {
    return (
      <div class={styles.videoOrder}>
        <CellGroup border={false}>
          <Cell titleClass={styles.title} title="课程名称" />
          <Cell
            title={orderStatus.videoInfo.courseGroupName}
            v-slots={{
              default: () => (
                <span class={styles.price}>
                  <i>¥</i>
                  {(this as any).$filters.moneyFormat(
                    orderStatus.videoInfo.coursePrice
                  )}
                </span>
              )
            }}
          />
        </CellGroup>

        <CellGroup border={false}>
          <Cell titleClass={styles.title} title="主讲老师" />
          <Cell
            class={styles.titleName}
            title={orderStatus.videoInfo.teacherName}
            v-slots={{
              icon: () => (
                <Image
                  class={styles.userLogo}
                  src={orderStatus.videoInfo.avatar || iconTeacher}
                />
              )
            }}
          />
        </CellGroup>

        {/* <CellGroup border={false}>
          <Cell
            titleClass={styles.title}
            title="上课时间"
            value={`（共${this.coursePlan.length}课时）`}
          />
          <Cell
            v-slots={{
              title: () => (
                <div>
                  {this.coursePlan.map((item: any) => (
                    <div class={styles.classItem}>
                      <div class={styles.time}>{item.createTime}</div>
                    </div>
                  ))}
                </div>
              )
            }}
          />
        </CellGroup> */}
      </div>
      // 视频课
    )
  }
})
